@@ -18,6 +18,7 @@ use licenses::{detect_project_license, is_license_compatible, LicenseCompatibili
 use parser::parse_root;
 use reporter::{generate_report, ReportConfig};
 use sbom::handle_sbom_command;
+use sbom::validate::handle_sbom_validate_command;
 use std::env;
 use std::path::Path;
 use std::process;
@@ -44,6 +45,7 @@ struct CheckConfig {
     gist: bool,
     osi: Option<cli::OsiFilter>,
     strict: bool,
+    no_local: bool,
 }
 
 fn main() {
@@ -113,15 +115,6 @@ fn run() -> FeludaResult<()> {
         &format!("Analysing project at: {}", analysis_path.display()),
     );
 
-    // Handle SBOM generation if requested
-    if let Some(sbom_format) = &args.sbom {
-        return handle_sbom_command(
-            analysis_path.to_string_lossy().to_string(),
-            sbom_format,
-            args.output_file.clone(),
-        );
-    }
-
     // Handle the command based on whether a subcommand was provided
     if args.is_default_command() {
         // Default behavior: license analysis
@@ -142,6 +135,7 @@ fn run() -> FeludaResult<()> {
             gist: args.gist,
             osi: args.osi,
             strict: args.strict,
+            no_local: args.no_local,
         };
         handle_check_command(config)
     } else {
@@ -156,6 +150,49 @@ fn run() -> FeludaResult<()> {
                 handle_generate_command(path, language, project_license);
                 Ok(())
             }
+            Commands::Sbom {
+                path,
+                format,
+                output,
+            } => {
+                // Determine which format to use
+                match format {
+                    Some(cli::SbomCommand::Spdx {
+                        path: fmt_path,
+                        output: fmt_output,
+                    }) => {
+                        // Use the subcommand path/output if provided, otherwise use the parent command's
+                        let final_path = if fmt_path != "./" {
+                            fmt_path
+                        } else {
+                            path.clone()
+                        };
+                        let final_output = fmt_output.or(output.clone());
+                        handle_sbom_command(final_path, &cli::SbomFormat::Spdx, final_output)
+                    }
+                    Some(cli::SbomCommand::Cyclonedx {
+                        path: fmt_path,
+                        output: fmt_output,
+                    }) => {
+                        let final_path = if fmt_path != "./" {
+                            fmt_path
+                        } else {
+                            path.clone()
+                        };
+                        let final_output = fmt_output.or(output.clone());
+                        handle_sbom_command(final_path, &cli::SbomFormat::Cyclonedx, final_output)
+                    }
+                    Some(cli::SbomCommand::Validate {
+                        sbom_file,
+                        output: validation_output,
+                        json,
+                    }) => handle_sbom_validate_command(sbom_file, validation_output, json),
+                    None => {
+                        // Default: generate both formats
+                        handle_sbom_command(path, &cli::SbomFormat::All, output)
+                    }
+                }
+            }
         }
     }
 }
@@ -209,8 +246,13 @@ fn handle_check_command(config: CheckConfig) -> FeludaResult<()> {
     }
 
     // Parse and analyze dependencies
-    let mut analyzed_data = parse_root(&config.path, config.language.as_deref(), config.strict)
-        .map_err(|e| FeludaError::Parser(format!("Failed to parse dependencies: {e}")))?;
+    let mut analyzed_data = parse_root(
+        &config.path,
+        config.language.as_deref(),
+        config.strict,
+        config.no_local,
+    )
+    .map_err(|e| FeludaError::Parser(format!("Failed to parse dependencies: {e}")))?;
 
     log_debug("Analyzed dependencies", &analyzed_data);
 
