@@ -437,9 +437,9 @@ mod tests {
             fail_on_incompatible: false,
             project_license: None,
             gist: false,
-            sbom: None,
             osi: None,
             strict: false,
+            no_local: false,
         };
 
         let result = clone_repository(&args, temp_dir.path());
@@ -492,9 +492,9 @@ mod tests {
             fail_on_incompatible: false,
             project_license: None,
             gist: false,
-            sbom: None,
             osi: None,
             strict: false,
+            no_local: false,
         };
 
         // Enable debug mode for this test
@@ -546,9 +546,9 @@ mod tests {
             fail_on_incompatible: false,
             project_license: None,
             gist: false,
-            sbom: None,
             osi: None,
             strict: false,
+            no_local: false,
         };
 
         let result = clone_repository(&args, temp_dir.path());
